@@ -160,8 +160,8 @@ authorship claim or copyright claim to the contents of C<Alien::SDL::ConfigData>
 __DATA__
 do{ my $x = [
        {
-         'additional_cflags' => '-I/usr/include/smpeg -I/usr/include -I/usr/include -I/usr/local/include',
-         'additional_libs' => '-Wl,-rpath,/usr/local/lib -L/usr/lib -L/usr/local/lib -Wl,-rpath,/usr/lib',
+         'additional_cflags' => '-I/usr/include/smpeg -I/usr/include -I/usr/local/include -I/usr/include',
+         'additional_libs' => '-Wl,-rpath,/usr/lib -Wl,-rpath,/usr/local/lib -L/usr/local/lib -L/usr/lib',
          'build_arch' => 'armv6l-linux-thread-multi',
          'build_cc' => 'cc',
          'build_os' => 'linux',
